---
description: Build and use MCAP C++ library with CMake.
---

# Build MCAP with CMake

If you want to add MCAP to your C++ project that uses CMake, the third-party [olympus-robotics/mcap_builder](https://github.com/olympus-robotics/mcap_builder) repository provides a helpful wrapper.

The readme file in that repository provides the steps and the context needed.
